@@ -1,5 +1,4 @@
 import openpyxl
-from datetime import datetime
 
 from . import xltypes
 
@@ -12,7 +11,7 @@ class Reader():
     def read(self):
         self.book = openpyxl.load_workbook(self.excel_file_name)
 
-    def read_defined_names(self, ignore_sheets = [], ignore_hidden = False):
+    def read_defined_names(self, ignore_sheets=[], ignore_hidden=False):
         return {
             defn.name: defn.value
             for defn in self.book.defined_names.definedName
@@ -37,10 +36,7 @@ class Reader():
                     formula = None
                     value = cell.value
 
-                # Convert date/time back to number.
-                if isinstance(value, (datetime)):
-                    value = openpyxl.utils.datetime.to_excel(value)
-
-                cells[addr] = xltypes.XLCell(addr, value=value, formula=formula)
+                cells[addr] = xltypes.XLCell(
+                    addr, value=value, formula=formula)
 
         return [cells, formulae, ranges]
